summaryrefslogtreecommitdiffstats
path: root/third_party/libjingle
diff options
context:
space:
mode:
authorakalin@chromium.org <akalin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-01 02:39:04 +0000
committerakalin@chromium.org <akalin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-01 02:39:04 +0000
commit196d0b8189d0ed873adb87aa21beface3f4002b0 (patch)
tree876d0ce55a1f1f16af12cc0902babd6bd20411df /third_party/libjingle
parentb23d7883de40a45db7852bcbbcdeb491bb0daae2 (diff)
downloadchromium_src-196d0b8189d0ed873adb87aa21beface3f4002b0.zip
chromium_src-196d0b8189d0ed873adb87aa21beface3f4002b0.tar.gz
chromium_src-196d0b8189d0ed873adb87aa21beface3f4002b0.tar.bz2
Quick fix for a problem introduced by 41865 which causes sync notifications
to break for non-gmail.com accounts. BUG=40054 TEST=manual testing Review URL: http://codereview.chromium.org/1523007 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@43310 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'third_party/libjingle')
-rw-r--r--third_party/libjingle/files/talk/xmpp/xmppclient.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/third_party/libjingle/files/talk/xmpp/xmppclient.cc b/third_party/libjingle/files/talk/xmpp/xmppclient.cc
index ec68215..b0f3138 100644
--- a/third_party/libjingle/files/talk/xmpp/xmppclient.cc
+++ b/third_party/libjingle/files/talk/xmpp/xmppclient.cc
@@ -123,11 +123,12 @@ XmppClient::Connect(const XmppClientSettings & settings,
// the jid's domain to be used. "foo@example.com" -> stream to="example.com"
// tls certificate for "example.com"
//
// This is only true when using Gaia auth, so let's say if there's no preauth,
// we should use the actual server name
if ((settings.server().IPAsString() == buzz::STR_TALK_GOOGLE_COM ||
settings.server().IPAsString() == buzz::STR_TALKX_L_GOOGLE_COM) &&
- pre_auth != NULL) {
+ sasl_handler != NULL) {
d_->engine_->SetTlsServer(buzz::STR_GMAIL_COM, buzz::STR_GMAIL_COM);
}
@@ -123,11 +123,12 @@ XmppClient::Connect(const XmppClientSettings & settings,
// tls certificate for "example.com"
//
- // This is only true when using Gaia auth, so let's say if there's no preauth,
- // we should use the actual server name
+ // This is only true when using Gaia auth, so let's say if there's
+ // no sasl_handler, we should use the actual server name
+ // TODO(akalin): Do this in a less hackish way.
if ((settings.server().IPAsString() == buzz::STR_TALK_GOOGLE_COM ||
settings.server().IPAsString() == buzz::STR_TALKX_L_GOOGLE_COM) &&